@@ -1,7 +1,7 @@
 """
 Hatchling build hook.
 
-This hook is responsible for download the Pact FFI library and building the
+This hook is responsible for downloading the Pact FFI library and building the
 CFFI bindings for it.
 """
 
@@ -15,12 +15,15 @@ import sys
 import tempfile
 import urllib.request
 from pathlib import Path
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 import cffi
 from hatchling.builders.hooks.plugin.interface import BuildHookInterface
 from packaging.tags import sys_tags
 
+if TYPE_CHECKING:
+    from collections.abc import Mapping, MutableMapping, Sequence
+
 PKG_DIR = Path(__file__).parent.resolve() / "src" / "pact_ffi"
 PACT_LIB_URL = "https://github.com/pact-foundation/pact-reference/releases/download/libpact_ffi-v{version}/{prefix}pact_ffi-{os}-{platform}{suffix}.{ext}"
 
@@ -56,7 +59,7 @@ class PactBuildHook(BuildHookInterface[Any]):
 
     PLUGIN_NAME = "pact-ffi"
 
-    def __init__(self, *args: object, **kwargs: object) -> None:
+    def __init__(self, *args: Any, **kwargs: Any) -> None:  # noqa: ANN401
         """
         Initialize the build hook.
 
@@ -73,7 +76,7 @@ class PactBuildHook(BuildHookInterface[Any]):
         """
         shutil.rmtree(self.tmpdir, ignore_errors=True)
 
-    def clean(self, versions: list[str]) -> None:  # noqa: ARG002
+    def clean(self, versions: Sequence[str]) -> None:  # noqa: ARG002
         """
         Code called to clean.
 
@@ -93,7 +96,7 @@ class PactBuildHook(BuildHookInterface[Any]):
     def initialize(
         self,
         version: str,  # noqa: ARG002
-        build_data: dict[str, object],
+        build_data: MutableMapping[str, object],
     ) -> None:
         """
         Code called immediately before each build.
@@ -103,8 +106,8 @@ class PactBuildHook(BuildHookInterface[Any]):
                 Not used (but required by the parent class).
 
             build_data:
-                A dictionary to modify in-place used by Hatch when creating the
-                final wheel.
+                A mutable mapping to modify in-place used by Hatch when creating
+                the final wheel.
 
         Raises:
             UnsupportedPlatformError:
@@ -122,6 +125,7 @@ class PactBuildHook(BuildHookInterface[Any]):
         except UnsupportedPlatformError as err:
             msg = f"Pact FFI library is not available for {err.platform}"
             self.app.display_error(msg)
+            raise
 
         self.app.display_debug(f"Wheel artefacts: {build_data['force_include']}")
         build_data["tag"] = self._infer_tag()
@@ -134,7 +138,7 @@ class PactBuildHook(BuildHookInterface[Any]):
         """
         return next(t.platform for t in sys_tags())
 
-    def _install(self, version: str) -> dict[str, str]:
+    def _install(self, version: str) -> Mapping[str, str]:
         """
         Install the Pact library binary.
 
@@ -376,7 +380,7 @@ class PactBuildHook(BuildHookInterface[Any]):
             url:
                 The URL to download
 
-        Return:
+        Returns:
             The path to the downloaded artefact.
         """
         filename = url.split("/")[-1]
@@ -402,7 +406,7 @@ class PactBuildHook(BuildHookInterface[Any]):
         While the ABI3 interface was introduced in Python 3.2, we target the
         earliest supported version of Python in the Python wrapper.
 
-        Return:
+        Returns:
             The tag for the current build.
         """
         python_version = f"{sys.version_info.major}{sys.version_info.minor}"
